Cheshire3 Objects: Logger

|  | ## Cheshire3 Objects: Logger

Description

Logger objects handle all of the Cheshire3 logging requirements. They are responsable for caching, if necessary, and writing log files based on the data given to them.

Implementations

- logger.SimpleLogger
  Given a string, it will log it to stdout, stderr or a file.
- logger.FunctionLogger
  A logger that will record all of the function invocation details. Called from a seamless function wrapper.

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | domNode, parentObject |  | The constructer takes a DOM tree containing the configuration of the index and the object which the database should consider as its parent, normally a database.
log | *args, **kw | None | Logs the data given